summaryrefslogtreecommitdiffstats
path: root/interfaces/kimproxy/interface/kimiface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /interfaces/kimproxy/interface/kimiface.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'interfaces/kimproxy/interface/kimiface.h')
-rw-r--r--interfaces/kimproxy/interface/kimiface.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/interfaces/kimproxy/interface/kimiface.h b/interfaces/kimproxy/interface/kimiface.h
index dcf210f23..f3212df6d 100644
--- a/interfaces/kimproxy/interface/kimiface.h
+++ b/interfaces/kimproxy/interface/kimiface.h
@@ -179,7 +179,7 @@ k_dcop:
*
* @see allContacts()
* @see presenceString()
- * @see presencetqStatus()
+ * @see presenceStatus()
* @see KABC::Addressee::uid()
*/
virtual bool isPresent( const TQString & uid ) = 0;
@@ -197,7 +197,7 @@ k_dcop:
*
* @see isPresent()
* @see presenceString()
- * @see presencetqStatus()
+ * @see presenceStatus()
* @see KABC::Addressee::uid()
*/
virtual TQString displayName( const TQString & uid ) = 0;
@@ -214,7 +214,7 @@ k_dcop:
* TQString::null if the UID is unknown
*
* @see isPresent()
- * @see presencetqStatus()
+ * @see presenceStatus()
* @see KABC::Addressee::uid()
*/
virtual TQString presenceString( const TQString & uid ) = 0;
@@ -247,7 +247,7 @@ k_dcop:
* @see presenceString()
* @see KABC::Addressee::uid()
*/
- virtual int presencetqStatus( const TQString & uid ) = 0;
+ virtual int presenceStatus( const TQString & uid ) = 0;
/**
* @brief Indicate if a given contact can receive files
@@ -309,7 +309,7 @@ k_dcop:
*
* @see isPresent()
* @see presenceString()
- * @see presencetqStatus()
+ * @see presenceStatus()
* @see KABC::Addressee::uid()
*/
virtual TQPixmap icon( const TQString & uid ) = 0;
@@ -467,7 +467,7 @@ k_dcop_signals:
/**
* @brief Indicates that a contact's presence has changed
*
- * Notifies connected DCOP tqreceivers about a change in a contact's
+ * Notifies connected DCOP receivers about a change in a contact's
* presence.
*
* Implementations just have to call this method with the appropriate
@@ -476,9 +476,9 @@ k_dcop_signals:
* @param uid the KABC UID whose presence changed
* @param appId the DCOP application ID of the program the signal
* originates from
* @param presence the new presence's numeric value. See presencetqStatus()
*
- * @see presencetqStatus()
+ * @see presenceStatus()
* @see KABC::Addressee::uid()
* @see DCOPClient::appId()
*/
@@ -476,9 +476,9 @@ k_dcop_signals:
* @param appId the DCOP application ID of the program the signal
* originates from
- * @param presence the new presence's numeric value. See presencetqStatus()
+ * @param presence the new presence's numeric value. See presenceStatus()
*